============
widget-party
============

A Django-Dashing Widget Pack

Quick start
-----------

1. Add "widget_party" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = (
        ...
        'widget_party',
    )

2. DONE.
